Churro provides simple filesystem based persistent of an object tree using JSON,
based on `AcidFS <http://pypi.python.org/pypi/acidfs/1.0>`_.  

Full documentation is available at `Read the Docs 
<http://churro.readthedocs.org/>`_.
